@@ -20,25 +20,24 @@
 #include "config.h"
 #include <stdio.h>
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-macros.h>
+#include <glib/gi18n.h>
+#include <gtk/gtkicontheme.h>
 #include <libgnome/gnome-program.h>
 #include <gconf/gconf-client.h>
 
 #include "headers.h"
 #include "splash-widget.h"
 
-GNOME_CLASS_BOILERPLATE (SplashWidget,
-			 splash_widget,
-			 GObject,
-			 GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (SplashWidget,
+               splash_widget,
+               GTK_TYPE_WINDOW);
 
 static gboolean update_trans_effect (gpointer);
 
 typedef struct {
-	char *human_name;
-	char *exe;
-	char *icon;
+	const char *human_name;
+	const char *exe;
+	const char *icon;
 } SplashApp;
 
 static const SplashApp splash_map_table[] = {
@@ -149,30 +148,21 @@ splash_widget_expose_event (GtkWidget      *widget,
 	if (!GTK_WIDGET_DRAWABLE (widget))
 		return FALSE;
 
-	if (gdk_rectangle_intersect (
-		&event->area, &sw->image_bounds, &exposed))
-		gdk_draw_drawable  (
-			GDK_DRAWABLE (widget->window),
-			widget->style->black_gc,
-			GDK_DRAWABLE (sw->bg_pixmap),
-			exposed.x, exposed.y,
-			exposed.x, exposed.y,
-			exposed.width, exposed.height);
-
 	for (l = sw->icons; l; l = l->next) {
 		SplashIcon *si = l->data;
 
 		if (gdk_rectangle_intersect (&event->area,
 					     &si->position,
 					     &exposed))
-			gdk_pixbuf_render_to_drawable (
-				si->scaled, widget->window,
+			gdk_draw_pixbuf (
+			        widget->window,
 				widget->style->black_gc,
+				si->scaled,
 				exposed.x - si->position.x,
 				exposed.y - si->position.y,
 				exposed.x, exposed.y,
 				exposed.width, exposed.height,
-				GDK_RGB_DITHER_NORMAL,
+				GDK_RGB_DITHER_MAX,
 				exposed.x, exposed.y);
 	}
 
@@ -212,7 +202,7 @@ splash_widget_size_allocate (GtkWidget     *widget,
 
 	sw->image_bounds = *allocation;
 
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, size_allocate, (widget, allocation));
+	GTK_WIDGET_CLASS (splash_widget_parent_class)->size_allocate (widget, allocation);
 }
 
 static void
@@ -233,50 +223,46 @@ splash_widget_size_request (GtkWidget      *widget,
 static void
 splash_widget_realize (GtkWidget *widget)
 {
-	GdkPixmap *pm;
 	SplashWidget *sw = (SplashWidget *) widget;
 
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
+	GTK_WIDGET_CLASS (splash_widget_parent_class)->realize (widget);
 
 	if (sw->background && widget->window) {
-		int width, height;
+		GdkPixmap *pixmap;
+		GdkBitmap *mask;
+		GdkColormap *colormap;
 
-		width = gdk_pixbuf_get_width  (sw->background);
-		height = gdk_pixbuf_get_height (sw->background);
+		pixmap = NULL;
+		mask = NULL;
 
-		pm = gdk_pixmap_new (
-			widget->window,
-			width, height,
-			gdk_drawable_get_visual (widget->window)->depth);
+		colormap = gtk_widget_get_colormap (widget);
+		gdk_pixbuf_render_pixmap_and_mask_for_colormap (sw->background,
+							 	colormap,
+								&pixmap, &mask,
+								125);
 
-		if (pm) {
-			gdk_pixbuf_render_to_drawable (
-				sw->background, GDK_DRAWABLE (pm),
-				widget->style->black_gc,
-				0, 0, 0, 0, width, height,
-				GDK_RGB_DITHER_NORMAL,
-				0, 0);
-			
-			gdk_window_set_back_pixmap (
-				widget->window, pm, FALSE);
-			sw->bg_pixmap = pm;
+		if (pixmap) {
+			GtkStyle *style;
+
+			style = gtk_style_copy (widget->style);
+			style->bg_pixmap[GTK_STATE_NORMAL] = pixmap;
+
+			gtk_widget_set_style (widget, style);
+			g_object_unref (style);
+
+			if (mask) {
+				gdk_window_shape_combine_mask (widget->window,
+							       mask, 0, 0);
+
+				g_object_unref (mask);
+			}
+
+			gtk_style_set_background (widget->style, widget->window,
+						  GTK_STATE_NORMAL);
 		}
 	}
 }
 
-static void
-splash_widget_unrealize (GtkWidget *widget)
-{
-	SplashWidget *sw = (SplashWidget *) widget; 
-
-	if (sw->bg_pixmap) {
-		g_object_unref (sw->bg_pixmap);
-		sw->bg_pixmap = NULL;
-	}
-
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, unrealize, (widget));
-}
-
 static void
 splash_icon_destroy (SplashIcon *si)
 {
@@ -294,9 +280,6 @@ splash_widget_finalize (GObject *object)
 {
 	SplashWidget *sw = (SplashWidget *) object;
 
-	g_object_unref (sw->icon_theme);
-	sw->icon_theme = NULL;
-        
 	g_list_foreach (sw->icons, (GFunc) splash_icon_destroy, NULL);
 	g_list_free (sw->icons);
 
@@ -307,7 +290,7 @@ splash_widget_finalize (GObject *object)
 	g_object_unref (sw->layout);
 	sw->layout = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (splash_widget_parent_class)->finalize (object);
 }
 
 static void
@@ -319,7 +302,6 @@ splash_widget_class_init (SplashWidgetClass *klass)
 	gobject_class->finalize = splash_widget_finalize;
 
 	widget_class->realize = splash_widget_realize;
-	widget_class->unrealize = splash_widget_unrealize;
 	widget_class->expose_event = splash_widget_expose_event;
 	widget_class->size_request = splash_widget_size_request;
 	widget_class->size_allocate = splash_widget_size_allocate;
@@ -380,7 +362,7 @@ load_background (SplashWidget *sw)
 }
 
 static void
-splash_widget_instance_init (SplashWidget *sw)
+splash_widget_init (SplashWidget *sw)
 {
 	GtkWindow *window;
 	PangoAttrList *attrs;
@@ -410,18 +392,18 @@ splash_widget_instance_init (SplashWidget *sw)
 	pango_layout_set_attributes (sw->layout, attrs);
 	pango_attr_list_unref (attrs);
 
-	sw->icon_theme = gnome_icon_theme_new ();
-        
 	load_background (sw);
 }
 
 static GdkPixbuf *
 get_splash_icon (SplashWidget *sw, const char *icon_name)
 {
-	char *fname;
+	GdkScreen *screen;
+	GtkIconTheme *icon_theme;
 	GdkPixbuf *pb;
 	char *icon_no_extension;
 	char *p;
+	char *fname;
 
 	icon_no_extension = g_strdup (icon_name);
 	p = strrchr (icon_no_extension, '.');
@@ -432,27 +414,21 @@ get_splash_icon (SplashWidget *sw, const char *icon_name)
 		*p = 0;
 	}
 
-	fname = gnome_icon_theme_lookup_icon (sw->icon_theme,
-					      icon_no_extension,
-					      48, /* icon size */
-					      NULL, NULL);
-	
+        screen = gtk_widget_get_screen (GTK_WIDGET (sw));
+        icon_theme = gtk_icon_theme_get_for_screen (screen);
+
+        pb = gtk_icon_theme_load_icon (icon_theme,
+                                       icon_no_extension,
+                                       48, /* icon size */
+                                       0, NULL);
 	g_free (icon_no_extension);
 
-	if (fname != NULL)
-		pb = gdk_pixbuf_new_from_file (fname, NULL);
-	else
-		pb = NULL;
-	
 	if (pb == NULL) {
-		g_free (fname);
 		fname = g_build_filename (GNOME_ICONDIR, icon_name, NULL);
-
 		pb = gdk_pixbuf_new_from_file (fname, NULL);
+		g_free (fname);
 	}
 	
-	g_free (fname);
-	
 	return pb;
 }
 
@@ -469,6 +445,9 @@ layout_icon (SplashWidget *sw, SplashIcon *si, GdkRectangle *area)
 			  (sw->icon_size + sw->icon_spacing) * sw->cur_y_row);
 	si->position.width = si->position.height = sw->icon_size;
 
+	if (gtk_widget_get_direction (GTK_WIDGET (sw)) == GTK_TEXT_DIR_RTL)
+		si->position.x = GTK_WIDGET (sw)->allocation.width - si->position.x - si->position.width;
+
 	sw->cur_x_offset += sw->icon_size + sw->icon_spacing;
 
 	if (area)
@@ -523,6 +502,8 @@ splash_widget_add_icon (SplashWidget *sw,
 {
 	const SplashApp *app;
 	char            *basename;
+	char            *text;
+	int              length;
 	GdkPixbuf       *pb = NULL;
 
 	g_return_if_fail (SPLASH_IS_WIDGET (sw));
@@ -544,32 +525,30 @@ splash_widget_add_icon (SplashWidget *sw,
 	if (!pb)
 		pb = get_splash_icon (sw, basename);
 
+	text = app && app->human_name ?  _(app->human_name) : basename;
+
+	/* re-draw the old text extents */
+	gtk_widget_queue_draw_area (GTK_WIDGET (sw),
+				    sw->text_box.x, sw->text_box.y,
+				    sw->text_box.width, sw->text_box.height);
+
+	length = strlen (text);
+	sw->font_size_attr->end_index = length;
+	pango_layout_set_text (sw->layout, text, length);
+	calc_text_box (sw);
+
+	/* re-draw the new text extents */
+	gtk_widget_queue_draw_area (GTK_WIDGET (sw),
+				    sw->text_box.x, sw->text_box.y,
+				    sw->text_box.width, sw->text_box.height);
+
+	g_free (basename);
+
 	if (pb) {
 		SplashIcon   *si;
 		GdkRectangle  area;
-		char         *text;
-		int           length;
 		TransParam   *tp;
 
-		text = app && app->human_name ?  _(app->human_name) : basename;
-
-		/* re-draw the old text extents */
-		gtk_widget_queue_draw_area (
-			GTK_WIDGET (sw),
-			sw->text_box.x, sw->text_box.y,
-			sw->text_box.width, sw->text_box.height);
-
-		length = strlen (text);
-		sw->font_size_attr->end_index = length;
-		pango_layout_set_text (sw->layout, text, length);
-		calc_text_box (sw);
-
-		/* re-draw the new text extents */
-		gtk_widget_queue_draw_area (
-			GTK_WIDGET (sw),
-			sw->text_box.x, sw->text_box.y,
-			sw->text_box.width, sw->text_box.height);
-
 		si = g_new0 (SplashIcon, 1);
 		si->unscaled = pb;
 
@@ -607,8 +586,6 @@ splash_widget_add_icon (SplashWidget *sw,
 						    area.width, area.height);
 		}
 	}
-
-	g_free (basename);
 }
 
 static SplashWidget *global_splash = NULL;
